==> pmml-model-gwt-1.2.0.jar: org/dmg/pmml/Quantile.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.adapters.DecimalAdapter;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="quantileLimit" use="required" type="{http://www.dmg.org/PMML-4_2}PERCENTAGE-NUMBER" />
 *       &lt;attribute name="quantileValue" use="required" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "Quantile", namespace = "http://www.dmg.org/PMML-4_2")
public class Quantile
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions
{

    @XmlAttribute(name = "quantileLimit", required = true)
    @XmlJavaTypeAdapter(DecimalAdapter.class)
    private Double quantileLimit;
    @XmlAttribute(name = "quantileValue", required = true)
    private double quantileValue;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_2")
    private List<Extension> extensions;

    public Quantile() {
        super();
    }

    public Quantile(final Double quantileLimit, final double quantileValue) {
        super();
        this.quantileLimit = quantileLimit;
        this.quantileValue = quantileValue;
    }

    /**
     * Gets the value of the quantileLimit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getQuantileLimit() {
        return quantileLimit;
    }

    /**
     * Sets the value of the quantileLimit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public Quantile setQuantileLimit(Double quantileLimit) {
        this.quantileLimit = quantileLimit;
        return this;
    }

    /**
     * Gets the value of the quantileValue property.
     * 
     */
    public double getQuantileValue() {
        return quantileValue;
    }

    /**
     * Sets the value of the quantileValue property.
     * 
     */
    public Quantile setQuantileValue(double quantileValue) {
        this.quantileValue = quantileValue;
        return this;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public Quantile addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
            status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
        }
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.3.9.jar: org/dmg/pmml/Quantile.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="quantileLimit" use="required" type="{http://www.dmg.org/PMML-4_3}PERCENTAGE-NUMBER" />
 *       &lt;attribute name="quantileValue" use="required" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "Quantile", namespace = "http://www.dmg.org/PMML-4_3")
public class Quantile
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<Quantile>
{

    @XmlAttribute(name = "quantileLimit", required = true)
    private double quantileLimit;
    @XmlAttribute(name = "quantileValue", required = true)
    private double quantileValue;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67305479L;

    public Quantile() {
    }

    public Quantile(
        @org.jpmml.model.Property("quantileLimit")
        double quantileLimit,
        @org.jpmml.model.Property("quantileValue")
        double quantileValue) {
        this.quantileLimit = quantileLimit;
        this.quantileValue = quantileValue;
    }

    /**
     * Gets the value of the quantileLimit property.
     * 
     */
    public double getQuantileLimit() {
        return quantileLimit;
    }

    /**
     * Sets the value of the quantileLimit property.
     * 
     */
    public Quantile setQuantileLimit(
        @org.jpmml.model.Property("quantileLimit")
        double quantileLimit) {
        this.quantileLimit = quantileLimit;
        return this;
    }

    /**
     * Gets the value of the quantileValue property.
     * 
     */
    public double getQuantileValue() {
        return quantileValue;
    }

    /**
     * Sets the value of the quantileValue property.
     * 
     */
    public Quantile setQuantileValue(
        @org.jpmml.model.Property("quantileValue")
        double quantileValue) {
        this.quantileValue = quantileValue;
        return this;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public Quantile addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
